Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3127)

Unified Diff: chrome/browser/spellchecker/feedback_sender.h

Issue 1545223002: Switch to standard integer types in chrome/browser/, part 4 of 4. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix Created 5 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/spellchecker/feedback.cc ('k') | chrome/browser/spellchecker/feedback_sender.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/spellchecker/feedback_sender.h
diff --git a/chrome/browser/spellchecker/feedback_sender.h b/chrome/browser/spellchecker/feedback_sender.h
index ec9755801a45ad357fca80ff362befa4a7891134..c98d5ba274ab8da364ef633fd90d2603f7bc6805 100644
--- a/chrome/browser/spellchecker/feedback_sender.h
+++ b/chrome/browser/spellchecker/feedback_sender.h
@@ -5,17 +5,22 @@
// An object to record and send user feedback to spelling service. The spelling
// service uses the feedback to improve its suggestions.
//
// Assigns uint32 hash identifiers to spelling suggestions from spelling service
// and stores these suggestions. Records user's actions on these suggestions.
// Periodically sends batches of user feedback to the spelling service.
#ifndef CHROME_BROWSER_SPELLCHECKER_FEEDBACK_SENDER_H_
#define CHROME_BROWSER_SPELLCHECKER_FEEDBACK_SENDER_H_
+#include <stddef.h>
+#include <stdint.h>
+
#include <map>
#include <set>
#include <vector>
+#include "base/macros.h"
#include "base/memory/scoped_vector.h"
#include "base/memory/weak_ptr.h"
#include "base/timer/timer.h"
@@ -61,24 +66,24 @@ class FeedbackSender : public base::SupportsWeakPtr<FeedbackSender>,
// Records that user selected suggestion |suggestion_index| for the
// misspelling identified by |hash|.
- void SelectedSuggestion(uint32 hash, int suggestion_index);
+ void SelectedSuggestion(uint32_t hash, int suggestion_index);
// Records that user added the misspelling identified by |hash| to the
// dictionary.
- void AddedToDictionary(uint32 hash);
+ void AddedToDictionary(uint32_t hash);
// Records that user right-clicked on the misspelling identified by |hash|,
// but did not select any suggestion.
- void IgnoredSuggestions(uint32 hash);
+ void IgnoredSuggestions(uint32_t hash);
// Records that user did not choose any suggestion but manually corrected the
// misspelling identified by |hash| to string |correction|, which is not in
// the list of suggestions.
- void ManuallyCorrected(uint32 hash, const base::string16& correction);
+ void ManuallyCorrected(uint32_t hash, const base::string16& correction);
// Records that user has the misspelling in the custom dictionary. The user
// will never see the spellcheck suggestions for the misspelling.
- void RecordInDictionary(uint32 hash);
+ void RecordInDictionary(uint32_t hash);
// Receives document markers for renderer with process ID |render_process_id|
// when the renderer responds to a RequestDocumentMarkers() call. Finalizes
@@ -87,7 +92,7 @@ class FeedbackSender : public base::SupportsWeakPtr<FeedbackSender>,
// service. If the current session has expired, then refreshes the session
// start timestamp and sends out all of the feedback data.
void OnReceiveDocumentMarkers(int renderer_process_id,
- const std::vector<uint32>& markers);
+ const std::vector<uint32_t>& markers);
// Generates feedback data based on spellcheck results. The new feedback data
// is pending. Sets hash identifiers for |results|. Called when spelling
« no previous file with comments | « chrome/browser/spellchecker/feedback.cc ('k') | chrome/browser/spellchecker/feedback_sender.cc » ('j') | no next file with comments »
@@ -5,17 +5,22 @@
// service uses the feedback to improve its suggestions.
//
-// Assigns uint32 hash identifiers to spelling suggestions from spelling service
-// and stores these suggestions. Records user's actions on these suggestions.
-// Periodically sends batches of user feedback to the spelling service.
+// Assigns uint32_t hash identifiers to spelling suggestions from spelling
+// service and stores these suggestions. Records user's actions on these
+// suggestions. Periodically sends batches of user feedback to the spelling
+// service.
#ifndef CHROME_BROWSER_SPELLCHECKER_FEEDBACK_SENDER_H_
#define CHROME_BROWSER_SPELLCHECKER_FEEDBACK_SENDER_H_

Powered by Google App Engine
This is Rietveld 408576698